@@ -6,7 +6,7 @@ use warnings;
 use Carp;
 use Module::Pluggable::Object ();
 
-our $VERSION = '0.25';
+our $VERSION = '0.27';
 
 =head1 NAME
 
@@ -195,15 +195,15 @@ sub _load {
             next unless $loader->is_supported;
             $supported = 1;
             my @configs;
-            my $ok = do {
+            my $err = do {
                 local $@;
                 @configs = eval { $loader->load( $filename, $loader_args{ $loader } ); };
-                1;
+                $@;
             };
 
             # fatal error if we used extension matching
-            croak "Error parsing $filename: $@" if !$ok and $use_ext_lut;
-            next if !$ok or !@configs;
+            croak "Error parsing $filename: $err" if $err and $use_ext_lut;
+            next if $err or !@configs;
 
             # post-process config with a filter callback
             if ( $args->{ filter } ) {
@@ -314,7 +314,7 @@ Config::Any requires no configuration files or environment variables.
 
 =head1 DEPENDENCIES
 
-L<Module::Pluggable|Module::Pluggable>
+L<Module::Pluggable::Object|Module::Pluggable::Object>
 
 And at least one of the following:
 L<Config::General|Config::General>
